@@ -24,20 +24,8 @@ def main(*args):
         stderr=subprocess.PIPE
     )
     stdout, stderr = proc.communicate()
-    with open('/tmp/taskcheck.out', 'w') as out:
-        out.write(
-            json.dumps(
-                {
-                    'stdout': stdout,
-                    'stderr': stderr,
-                    'retcode': proc.returncode,
-                    'date': str(datetime.datetime.now())
-                },
-                indent=4
-            )
-        )
     if proc.returncode != 0:
-        raise FailedToSynchronize(stderr)
+        raise FailedToSynchronize("%s: %s" % (proc.returncode, stderr))
     finished = time.time()
 
     total_duration = finished - started
